@@ -59,7 +59,7 @@ def gammacat():
     return SourceCatalogGammaCat(filename=filename)
 
 
-@requires_data("gammapy-data")
+@requires_data()
 class TestSourceCatalogGammaCat:
     def test_source_table(self, gammacat):
         assert gammacat.name == "gamma-cat"
@@ -95,7 +95,7 @@ class TestSourceCatalogGammaCat:
         assert_allclose(source.spectral_model.parameters["index"].value, 2.2)
 
 
-@requires_data("gammapy-data")
+@requires_data()
 class TestSourceCatalogObjectGammaCat:
     def test_data(self, gammacat):
         source = gammacat[0]
